@@ -18,6 +18,15 @@
 #include <sys/resource.h>
 
 
+static
+void
+write_log(const std::vector<std::string>  pref, const char *key, const bson_t *document) {
+    //size_t documentLength = 0;
+    //char *str = bson_as_canonical_extended_json (document, &documentLength);
+    //BOOST_LOG_TRIVIAL(debug) << "LOG-JSON " << key << " " << str;
+    //bson_free (str);
+}
+
 Chunk::Chunk (const uint8_t *data, size_t size, int64_t id=-1, bool logMetricNames=0) {
     compressed = new uint8_t[size];
     compressed_size = size;
@@ -180,6 +189,8 @@ static bool
 visit_array(const bson_iter_t *, const char *key, const bson_t *v_array, void *data) {
     auto *v = (visitResults *) data;
 
+    //::write_log(key, v_array);
+
     bson_iter_t child;
     if (bson_iter_init(&child, v_array)) {
         v->name_stack.emplace_back(key);
@@ -194,6 +205,9 @@ visit_document(const bson_iter_t *, const char *key, const bson_t *v_document, v
     auto *v = (visitResults *) data;
     bson_iter_t child;
     if (bson_iter_init(&child, v_document)) {
+
+        ::write_log(v->name_stack, key, v_document);
+
         v->name_stack.emplace_back(key);
         ::bson_iter_visit_all(&child, v->visit_table, data);
         v->name_stack.pop_back();
@@ -241,9 +255,9 @@ visit_double(const bson_iter_t *, const char *key, double v_double, void *data){
 static bool
 visit_timestamp(const bson_iter_t *, const char *key, uint32_t t1, uint32_t t2, void *data){
     auto *v = (visitResults *) data;
-    std::string s1 =  std::string(key) + "_1";
+    std::string s1 =  std::string(key) + "_t";
     v->metrics->emplace_back( new ChunkMetric(fullname( s1.c_str(), v->name_stack),  BSON_TYPE_INT32, t1));
-    std::string s2 =  std::string(key) + "_2";
+    std::string s2 =  std::string(key) + "_i";
     v->metrics->emplace_back( new ChunkMetric(fullname( s2.c_str(), v->name_stack),  BSON_TYPE_INT32, t2));
 
     if (v->logNames) {
@@ -270,6 +284,7 @@ visit_utf8(const bson_iter_t *, const char *key, size_t, const char *s, void *da
     return false;
 }
 
+//TODO:: Add?
 static bool
 visit_oid(const bson_iter_t *, const char *, const bson_oid_t *, void *data){
     return false;
@@ -302,6 +317,14 @@ Chunk::ConstructMetrics(const uint8_t* data ) {
     metrics.reserve(metricsInChunk);
 
     if ((b = bson_new_from_data (data, (size_t)(*dataSize)))) {
+
+        // -
+        size_t length = 0;
+        char *str = bson_as_json (b, &length);
+        //printf ("%s\n", str);
+        bson_free (str);
+        // -
+
         if (bson_iter_init (&iter, b)) {
 
             bson_visitor_t vt{};
