@@ -48,7 +48,12 @@ public:
                                         size_t start=Dataset::INVALID_TIMESTAMP, size_t end=Dataset::INVALID_TIMESTAMP,
                                         bool ratedMetric=false);
 
+    size_t dumpDocsAsJson(std::string inputFile, std::string outputFile);
+
 private:
+
+     std::string getMetricAsJSONDoc(std::vector<std::string>*metricNames, size_t pos);
+
      ParserTasksList parserTasks;
      Dataset dataSet;
      std::vector<std::string> metadata;
