@@ -103,6 +103,12 @@ struct ParserClass {
         return -1;
     }
 
+    int dumpFileAsJson(std::string input, std::string output) {
+
+
+        return pParser->dumpDocsAsJson(input, output);
+    }
+
     py::list
     getParsedFileInfo() {
         auto fi = pParser->getParsedFileInfo();
@@ -250,6 +256,10 @@ PYBIND11_MODULE(_core, m) {
              py::arg("file"))
         .def("get_parsed_file_info", &ParserClass::getParsedFileInfo,
              "Returns information on parsed files")
+        .def("dump_file_as_json", &ParserClass::dumpFileAsJson,
+             "Dumps a file contents to a file as JSON structures.",
+             py::arg("input"),
+             py::arg("output"))
         .def("get_metric", &ParserClass::getMetric,
              "Returns a list of values from the metrics, using starting and ending timestamps if specified",
              py::arg("metric_name"),
