@@ -991,5 +991,19 @@ BOOST_AUTO_TEST_SUITE(ftdc_basic_suite)
     }
 
 
+
+    BOOST_AUTO_TEST_CASE(dump_json) {     //
+        // Create parser
+        auto parser = new FTDCParser();
+
+        std::vector<std::string> fileList;
+        for (auto &&fileInPath: std::filesystem::directory_iterator(DATA_TEST_DIR))
+            fileList.push_back(fileInPath.path().string());
+
+        parser->dumpDocsAsJson(fileList[0], "output.json" );
+
+
+    }
+
 BOOST_AUTO_TEST_SUITE_END()
 
